@@ -5,13 +5,12 @@ use 5.006002;
 use strict;
 use warnings;
 
-use Exporter ();
-our @ISA = qw{ Exporter };
+use base qw{ Exporter };
 
 use Carp;
 use Test::More 0.88;
 
-our $VERSION = '0.011_01';
+our $VERSION = '0.008';
 
 our %EXPORT_TAGS = (
     const	=> [ qw{ IS_WINDOWS } ],
@@ -154,6 +153,7 @@ This class supports the following public methods:
 
 This class has the following attributes:
 
+
 =head1 SEE ALSO
 
 <<< replace or remove boilerplate >>>
@@ -161,9 +161,7 @@ This class has the following attributes:
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Win32API-File-Time>,
-L<https://github.com/trwyant/perl-Win32API-File-Time/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -171,7 +169,7 @@ Tom Wyant (wyant at cpan dot org)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2017, 2019-2021 by Thomas R. Wyant, III
+Copyright (C) 2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
