@@ -52,33 +52,34 @@ supply of tuits.
 
 package Win32API::File::Time;
 
+use 5.006002;
+
 use strict;
 use warnings;
 
 use base qw{Exporter};
-use vars qw{
-	$FileTimeToSystemTime
-	$FileTimeToLocalFileTime
-	$GetFileTime
-	$LocalFileTimeToFileTime
-	$SetFileTime
-	$SystemTimeToFileTime
-	};
+
+our $FileTimeToSystemTime;
+our $FileTimeToLocalFileTime;
+our $GetFileTime;
+our $LocalFileTimeToFileTime;
+our $SetFileTime;
+our $SystemTimeToFileTime;
 
 use Carp;
 use Time::Local;
 use Win32::API;
-use Win32API::File qw{:ALL};
+use Win32API::File qw{ :ALL };
 
-our $VERSION = '0.007';
+our $VERSION = '0.008';
 
-our @EXPORT_OK = qw{GetFileTime SetFileTime utime};
+our @EXPORT_OK = qw{ GetFileTime SetFileTime utime };
 our %EXPORT_TAGS = (
-    all => [@EXPORT_OK],
-    win => [qw{GetFileTime SetFileTime}],
-    );
+    all => [ @EXPORT_OK ],
+    win => [ qw{ GetFileTime SetFileTime } ],
+);
 
-=item ($atime, $mtime, $ctime) = GetFileTime ($filename);
+=item ( $atime, $mtime, $ctime ) = GetFileTime( $filename );
 
 This subroutine returns the access, modification, and creation times of
 the given file. If it fails, nothing is returned, and the error code
@@ -91,19 +92,20 @@ has been exposed for orthogonality's sake.
 =cut
 
 sub GetFileTime {
-my $fn = shift or croak "usage: GetFileTime (filename)";
-my $fh = _get_handle ($fn) or return;
-$GetFileTime ||= _map ('KERNEL32', 'GetFileTime', [qw{N P P P}], 'I');
-my ($atime, $mtime, $ctime);
-$atime = $mtime = $ctime = pack 'LL', 0, 0;	# Preallocate 64 bits.
-$GetFileTime->Call ($fh, $ctime, $atime, $mtime) or
-    return _close_handle ($fh);
-CloseHandle ($fh);
-return _filetime_to_perltime ($atime, $mtime, $ctime);
+    my ( $fn ) = @_;
+    defined $fn
+	or croak "usage: GetFileTime (filename)";
+    my $fh = _get_handle( $fn ) or return;
+    $GetFileTime ||= _map( 'KERNEL32', 'GetFileTime', [ qw{ N P P P } ], 'I' );
+    my $atime = my $mtime = my $ctime = pack 'LL', 0, 0; # Preallocate 64 bits.
+    $GetFileTime->Call( $fh, $ctime, $atime, $mtime )
+	or return _close_handle( $fh );
+    CloseHandle( $fh );
+    return _filetime_to_perltime( $atime, $mtime, $ctime );
 }
 
 
-=item SetFileTime (filename, atime, mtime, ctime);
+=item SetFileTime( filename, atime, mtime, ctime );
 
 This subroutine sets the access, modification, and creation times of
 the given file. The return is true for success, and false for failure.
@@ -112,30 +114,33 @@ In the latter case, $^E will contain the error.
 If you don't want to set all of the times, pass 0 or undef for the
 times you don't want to set. For example,
 
- $now = time ();
- SetFileTime ($filename, $now, $now);
+ $now = time();
+ SetFileTime( $filename, $now, $now );
 
 is equivalent to the "touch" command for the given file.
 
 =cut
 
 sub SetFileTime {
-my $fn = shift or croak "usage: SetFileTime (filename, atime, mtime, ctime)";
-my $atime = _perltime_to_filetime (shift);
-my $mtime = _perltime_to_filetime (shift);
-my $ctime = _perltime_to_filetime (shift);
-# We assume we can do something useful for an undef.
-$SetFileTime ||= _map ('KERNEL32', 'SetFileTime', [qw{N P P P}], 'I');
-my $fh = _get_handle ($fn, 1) or return;
+    my ( $fn, $atime, $mtime, $ctime ) = @_;
+    defined $fn
+	or croak "usage: SetFileTime (filename, atime, mtime, ctime)";
+    foreach ( $atime, $mtime, $ctime ) {
+	$_ = _perltime_to_filetime( $_ );
+    }
+    # We assume we can do something useful for an undef.
+    $SetFileTime ||= _map( 'KERNEL32', 'SetFileTime', [ qw{ N P P P } ], 'I' );
+    my $fh = _get_handle( $fn, 1 )
+	or return;
 
-$SetFileTime->Call ($fh, $ctime, $atime, $mtime) or
-    return _close_handle ($fh);
+    $SetFileTime->Call( $fh, $ctime, $atime, $mtime )
+	or return _close_handle( $fh );
 
-CloseHandle ($fh);
-return 1;
+    CloseHandle( $fh );
+    return 1;
 }
 
-=item utime ($atime, $mtime, $filename, ...)
+=item utime( $atime, $mtime, $filename, ... )
 
 This subroutine overrides the built-in of the same name. It does
 exactly the same thing, but has a different idea than the built-in
@@ -148,12 +153,13 @@ error encountered.
 =cut
 
 sub utime {	## no critic (ProhibitBuiltinHomonyms)
-my ( $atime, $mtime, @args ) = @_;
-my $num = 0;
-foreach my $fn (@args) {
-    SetFileTime ($fn, $atime, $mtime) and $num++;
+    my ( $atime, $mtime, @args ) = @_;
+    my $num = 0;
+    foreach my $fn (@args) {
+	SetFileTime ($fn, $atime, $mtime)
+	    and $num++;
     }
-return $num;
+    return $num;
 }
 
 
@@ -167,11 +173,11 @@ return $num;
 #	around the call.
 
 sub _close_handle {
-my $fh = shift;
-my $err = Win32::GetLastError ();
-CloseHandle ($fh);
-$^E = $err;	## no critic (RequireLocalizedPunctuationVars)
-return;
+    my ( $fh ) = @_;
+    my $err = Win32::GetLastError();
+    CloseHandle( $fh );
+    $^E = $err;	## no critic (RequireLocalizedPunctuationVars)
+    return;
 }
 
 
@@ -189,31 +195,32 @@ return;
 #	results of the stat () function.
 
 sub _filetime_to_perltime {
-my @args = @_;
-my @result;
-$FileTimeToSystemTime ||= _map (
-	'KERNEL32', 'FileTimeToSystemTime', [qw{P P}], 'I');
-$FileTimeToLocalFileTime ||= _map (
-	'KERNEL32', 'FileTimeToLocalFileTime', [qw{P P}], 'I');
-my $st = pack 'ssssssss', 0, 0, 0, 0, 0, 0, 0, 0;
-foreach my $ft (@args) {
-    my (undef, $high) = unpack 'LL', $ft;	# $low unused
-    $high or do {
-	push @result, undef;
-	next;
+    my @args = @_;
+    my @result;
+    $FileTimeToSystemTime ||= _map(
+	    'KERNEL32', 'FileTimeToSystemTime', [ qw{ P P } ], 'I' );
+    $FileTimeToLocalFileTime ||= _map (
+	    'KERNEL32', 'FileTimeToLocalFileTime', [qw{P P}], 'I');
+    my $st = pack 'ssssssss', 0, 0, 0, 0, 0, 0, 0, 0;
+    foreach my $ft ( @args ) {
+	my ( undef, $high ) = unpack 'LL', $ft;	# $low unused
+	$high or do {
+	    push @result, undef;
+	    next;
 	};
-    my $lf = $ft;	# Just to get the space allocated.
-    $FileTimeToLocalFileTime->Call ($ft, $lf) and
-	$FileTimeToSystemTime->Call ($lf, $st) or do {
-	push @result, undef;
-	next;
+	my $lf = $ft;	# Just to get the space allocated.
+	$FileTimeToLocalFileTime->Call ($ft, $lf)
+	    and $FileTimeToSystemTime->Call ($lf, $st)
+	    or do {
+	    push @result, undef;
+	    next;
 	};
-    my @tm = unpack 'ssssssss', $st;
-    push @result, $tm[0] > 0 ?
-	timelocal (@tm[6, 5, 4, 3], $tm[1] - 1, $tm[0]) :
-	undef;
+	my @tm = unpack 'ssssssss', $st;
+	push @result, $tm[0] > 0 ?
+	    timelocal (@tm[6, 5, 4, 3], $tm[1] - 1, $tm[0]) :
+	    undef;
     }
-return wantarray ? @result : $result[0];
+    return wantarray ? @result : $result[0];
 }
 
 
@@ -225,31 +232,30 @@ return wantarray ? @result : $result[0];
 #	configured appropriately for reading attributes.
 
 sub _get_handle {
-my $fn = shift;
-my $write = shift;
+    my ( $fn, $write ) = @_;
 
-my $handle = ${^WIDE_SYSTEM_CALLS} ?
-    CreateFileW ($fn,
-	($write ? FILE_WRITE_ATTRIBUTES : FILE_READ_ATTRIBUTES),
-	($write ? FILE_SHARE_WRITE | FILE_SHARE_READ : FILE_SHARE_READ),
-	[],
-	OPEN_EXISTING,
-	($write ? FILE_ATTRIBUTE_NORMAL | FILE_FLAG_BACKUP_SEMANTICS : FILE_FLAG_BACKUP_SEMANTICS),
-	0,
-	) :
-    CreateFile ($fn,
-	($write ? FILE_WRITE_ATTRIBUTES : FILE_READ_ATTRIBUTES),
-	($write ? FILE_SHARE_WRITE | FILE_SHARE_READ : FILE_SHARE_READ),
-	[],
-	OPEN_EXISTING,
-	($write ? FILE_ATTRIBUTE_NORMAL | FILE_FLAG_BACKUP_SEMANTICS : FILE_FLAG_BACKUP_SEMANTICS),
-	0,
-	)
-  or do {
-    $^E = Win32::GetLastError ();	## no critic (RequireLocalizedPunctuationVars)
-    return;
+    my @arg = (
+	    FILE_READ_ATTRIBUTES,
+	    FILE_SHARE_READ,
+	    [],
+	    OPEN_EXISTING,
+	    FILE_FLAG_BACKUP_SEMANTICS,
+	    0
+    );
+    if ( $write ) {
+	$arg[0] = FILE_WRITE_ATTRIBUTES;
+	$arg[1] |= FILE_SHARE_WRITE;
+	$arg[4] |= FILE_ATTRIBUTE_NORMAL;
+    }
+    my $handle = ${^WIDE_SYSTEM_CALLS} ?
+	CreateFileW( $fn, @arg ) :
+	CreateFile( $fn, @arg )
+	or do {
+	$^E = Win32::GetLastError();	## no critic (RequireLocalizedPunctuationVars)
+	return;
     };
-return $handle;
+
+    return $handle;
 }
 
 
@@ -258,7 +264,7 @@ return $handle;
 #	This subroutine calls Win32API to map an entry point.
 
 sub _map {
-return Win32::API->new (@_) ||
+return Win32::API->new ( @_ ) ||
     croak "Error - Failed to map $_[1] from $_[0]: $^E";
 }
 
@@ -272,26 +278,25 @@ return Win32::API->new (@_) ||
 
 sub _perltime_to_filetime {
     my @args = @_;
-my @result;
-$SystemTimeToFileTime ||= _map (
-	'KERNEL32', 'SystemTimeToFileTime', [qw{P P}], 'I');
-$LocalFileTimeToFileTime ||= _map (
-	'KERNEL32', 'LocalFileTimeToFileTime', [qw{P P}], 'I');
-my $zero = pack 'LL', 0, 0;	# To get a quadword zero.
-my ($ft, $lf) = ($zero, $zero);	# To get the space allocated.
-foreach my $pt (@args) {
-    if (defined $pt) {
-	my @tm = localtime ($pt);
-	my $st = pack 'ssssssss', $tm[5] + 1900, $tm[4] + 1, 0,
-	    @tm[3, 2, 1, 0], 0;
-	push @result, $SystemTimeToFileTime->Call ($st, $lf)  &&
-	    $LocalFileTimeToFileTime->Call ($lf, $ft) ? $ft : $zero;
-	}
-      else {
-	push @result, $zero;
+    my @result;
+    $SystemTimeToFileTime ||= _map(
+	    'KERNEL32', 'SystemTimeToFileTime', [ qw{ P P } ], 'I' );
+    $LocalFileTimeToFileTime ||= _map(
+	    'KERNEL32', 'LocalFileTimeToFileTime', [ qw{ P P } ], 'I' );
+    my $zero = pack 'LL', 0, 0;	# To get a quadword zero.
+    my ( $ft, $lf ) = ( $zero, $zero );	# To get the space allocated.
+    foreach my $pt ( @args ) {
+	if ( defined $pt ) {
+	    my @tm = localtime ($pt);
+	    my $st = pack 'ssssssss', $tm[5] + 1900, $tm[4] + 1, 0,
+		@tm[3, 2, 1, 0], 0;
+	    push @result, $SystemTimeToFileTime->Call( $st, $lf )  &&
+		$LocalFileTimeToFileTime->Call( $lf, $ft ) ? $ft : $zero;
+	} else {
+	    push @result, $zero;
 	}
     }
-return wantarray ? @result : $result[0];
+    return wantarray ? @result : $result[0];
 }
 
 1;
